cmd

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: Apache-2.0 Imports: 17 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the Cmd command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the Cmd.

func New

func New() *cobra.Command

Types

This section is empty.

Directories

Path Synopsis
add
get
internal
cmd
test
Package test provides utilities for testing the OCM CLI commands.
Package test provides utilities for testing the OCM CLI commands.
get

Jump to