component_version

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: Apache-2.0 Imports: 24 Imported by: 0

Documentation

Index

Constants

const (
	FlagDryRun        = "dry-run"
	FlagOutput        = "output"
	FlagRecursive     = "recursive"
	FlagCopyResources = "copy-resources"
	FlagUploadAs      = "upload-as"
	FlagTransferSpec  = "transfer-spec"
)

Variables

This section is empty.

Functions

func New

func New() *cobra.Command

func TransferComponentVersion

func TransferComponentVersion(cmd *cobra.Command, args []string) error

Types

type UploadAs

type UploadAs int
const (
	// UploadAsDefault is the default upload mode, which is determined by the source and target repository.
	UploadAsDefault UploadAs = iota
	// UploadAsLocalBlob sets the upload of all oci resources as local blobs.
	UploadAsLocalBlob
	// UploadAsOciArtifact sets the upload of all oci resources as OCI artifacts.
	UploadAsOciArtifact
)

func (UploadAs) String

func (o UploadAs) String() string

Directories

Path Synopsis

Jump to