Documentation
¶
Index ¶
Constants ¶
const ( FlagDryRun = "dry-run" FlagOutput = "output" FlagRecursive = "recursive" FlagCopyResources = "copy-resources" FlagUploadAs = "upload-as" FlagTransferSpec = "transfer-spec" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type UploadAs ¶
type UploadAs int
const ( // UploadAsDefault is the default upload mode, which is determined by the source and target repository. UploadAsDefault UploadAs = iota // UploadAsLocalBlob sets the upload of all oci resources as local blobs. UploadAsLocalBlob // UploadAsOciArtifact sets the upload of all oci resources as OCI artifacts. UploadAsOciArtifact )
Click to show internal directories.
Click to hide internal directories.